OC.L10N.register(
    "files",
    {
    "Unknown error" : "يوچۇن خاتالىق",
    "Home" : "ئۆي",
    "Close" : "ياپ",
    "Favorites" : "يىغقۇچ",
    "Upload cancelled." : "يۈكلەشتىن ۋاز كەچتى.",
    "Uploading..." : "يۈكلەۋاتىدۇ…",
    "File upload is in progress. Leaving the page now will cancel the upload." : "ھۆججەت يۈكلەش مەشغۇلاتى ئېلىپ بېرىلىۋاتىدۇ. Leaving the page now will cancel the upload.",
    "Actions" : "مەشغۇلاتلار",
    "Download" : "چۈشۈر",
    "Rename" : "ئات ئۆزگەرت",
    "Delete" : "ئۆچۈر",
    "Unshare" : "ھەمبەھىرلىمە",
    "Files" : "ھۆججەتلەر",
    "Pending" : "كۈتۈۋاتىدۇ",
    "Name" : "ئاتى",
    "Size" : "چوڭلۇقى",
    "Modified" : "ئۆزگەرتكەن",
    "New" : "يېڭى",
    "Favorite" : "يىغقۇچ",
    "Folder" : "قىسقۇچ",
    "New folder" : "يېڭى قىسقۇچ",
    "Upload" : "يۈكلە",
    "Save" : "ساقلا",
    "Settings" : "تەڭشەكلەر",
    "WebDAV" : "WebDAV",
    "Upload too large" : "يۈكلەندىغىنى بەك چوڭ",
    "Text file" : "تېكىست ھۆججەت"
},
"nplurals=1; plural=0;");
